CPDFCircleAnnotation class annotations

Circle annotation model.

A circle shape annotation that extends CPDFAnnotation.

Key properties:

Serialization:

Inheritance

Constructors

CPDFCircleAnnotation({String title = "", required int page, String content = "", String uuid = '', DateTime? createDate, CPDFAnnotationMarkState markState = CPDFAnnotationMarkState.unmarked, CPDFAnnotationReviewState reviewState = CPDFAnnotationReviewState.none, required CPDFRectF rect, double borderWidth = 0, required Color borderColor, double borderAlpha = 255, required Color fillColor, double fillAlpha = 255, CPDFBorderEffectType effectType = CPDFBorderEffectType.solid, double dashGap = 0})
CPDFCircleAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

borderAlpha ↔ double
getter/setter pair
borderColor ↔ Color
getter/setter pair
borderWidth ↔ double
getter/setter pair
content ↔ String
getter/setter pairinherited
createDate → DateTime?
finalinherited
dashGap ↔ double
getter/setter pair
effectType ↔ CPDFBorderEffectType
getter/setter pair
fillAlpha ↔ double
getter/setter pair
fillColor ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
markState → CPDFAnnotationMarkState
finalinherited
page → int
finalinherited
rect → CPDFRectF
finalinherited
reviewState → CPDFAnnotationReviewState
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pairinherited
type → CPDFAnnotationType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited