CPDFFreeTextAnnotation class annotations

Free text annotation model.

A text-box style annotation that extends CPDFAnnotation.

Key properties:

Serialization:

Inheritance

Constructors

CPDFFreeTextAnnotation({required String title, required int page, required String content, required String uuid, DateTime? createDate, CPDFAnnotationMarkState markState = CPDFAnnotationMarkState.unmarked, CPDFAnnotationReviewState reviewState = CPDFAnnotationReviewState.none, required CPDFRectF rect, required CPDFTextAttribute textAttribute, double alpha = 255, CPDFAlignment alignment = CPDFAlignment.left})
CPDFFreeTextAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

alignment ↔ CPDFAlignment
getter/setter pair
alpha ↔ double
getter/setter pair
content ↔ String
getter/setter pairinherited
createDate → DateTime?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
markState → CPDFAnnotationMarkState
finalinherited
page → int
finalinherited
rect → CPDFRectF
finalinherited
reviewState → CPDFAnnotationReviewState
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAttribute ↔ CPDFTextAttribute
getter/setter pair
title ↔ String
getter/setter pairinherited
type → CPDFAnnotationType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited