CPDFImageAnnotation class annotations

Image annotation model.

An image-based stamp/annotation that extends CPDFAnnotation.

Key properties:

  • imageData: Preferred image source descriptor.

Serialization:

Inheritance

Constructors

CPDFImageAnnotation({String title = "", String content = "", DateTime? createDate, CPDFAnnotationMarkState markState = CPDFAnnotationMarkState.unmarked, CPDFAnnotationReviewState reviewState = CPDFAnnotationReviewState.none, required int page, String uuid = '', required CPDFRectF rect, CPDFImageData? imageData})
CPDFImageAnnotation.fromAsset({String? title, String? content, DateTime? createDate, required int page, String uuid = '', required CPDFRectF rect, required String assetPath})
Creates an image annotation from a Flutter asset path.
factory
CPDFImageAnnotation.fromBase64({String? title, String? content, DateTime? createDate, required int page, String uuid = '', required CPDFRectF rect, required String base64})
Creates an image annotation from a raw Base64 string.
factory
CPDFImageAnnotation.fromDataUri({String? title, String? content, DateTime? createDate, required int page, String uuid = '', required CPDFRectF rect, required String dataUri})
Creates an image annotation from a data URI string.
factory
CPDFImageAnnotation.fromJson(Map<String, dynamic> json)
Creates an image annotation from serialized JSON data.
factory
CPDFImageAnnotation.fromPath({String? title, String? content, DateTime? createDate, required int page, String uuid = '', required CPDFRectF rect, required String filePath})
Creates an image annotation from a local file path.
factory
CPDFImageAnnotation.fromUri({String? title, String? content, DateTime? createDate, required int page, String uuid = '', required CPDFRectF rect, required String uri})
Creates an image annotation from a platform URI string.
factory

Properties

content ↔ String
getter/setter pairinherited
createDate → DateTime?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
imageData → CPDFImageData?
Preferred image source for this annotation.
final
markState → CPDFAnnotationMarkState
finalinherited
page → int
finalinherited
rect → CPDFRectF
finalinherited
reviewState → CPDFAnnotationReviewState
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pairinherited
type → CPDFAnnotationType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited