CPDFInkAnnotation class annotations

Ink annotation model.

A freehand drawing annotation that extends CPDFAnnotation.

Key properties:

Serialization:

Inheritance

Constructors

CPDFInkAnnotation({String title = "", required int page, String content = "", String uuid = '', DateTime? createDate, CPDFAnnotationMarkState markState = CPDFAnnotationMarkState.unmarked, CPDFAnnotationReviewState reviewState = CPDFAnnotationReviewState.none, CPDFRectF rect = const CPDFRectF(left: 0, top: 0, right: 0, bottom: 0), required Color color, double alpha = 255, required double borderWidth, List<List<List<double>>>? inkPath})
CPDFInkAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

alpha ↔ double
getter/setter pair
borderWidth ↔ double
getter/setter pair
color ↔ Color
getter/setter pair
content ↔ String
getter/setter pairinherited
createDate → DateTime?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
inkPath → List<List<List<double>>>?
final
markState → CPDFAnnotationMarkState
finalinherited
page → int
finalinherited
rect → CPDFRectF
finalinherited
reviewState → CPDFAnnotationReviewState
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pairinherited
type → CPDFAnnotationType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited