CPDFLineAnnotation class annotations

Line annotation model.

A line/arrow annotation that extends CPDFAnnotation.

Key properties:

Note: This class may represent different types via type (e.g. CPDFAnnotationType.line or CPDFAnnotationType.arrow).

Serialization:

Inheritance

Constructors

CPDFLineAnnotation({required CPDFAnnotationType type, String title = "", required int page, String content = "", required String uuid, DateTime? createDate, CPDFAnnotationMarkState markState = CPDFAnnotationMarkState.unmarked, CPDFAnnotationReviewState reviewState = CPDFAnnotationReviewState.none, CPDFRectF rect = const CPDFRectF.isEmpty(), required double borderWidth, required Color borderColor, double borderAlpha = 255, required Color fillColor, double fillAlpha = 255, CPDFLineType lineHeadType = CPDFLineType.none, CPDFLineType lineTailType = CPDFLineType.none, double dashGap = 0, List<List<double>>? points})
CPDFLineAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

borderAlpha ↔ double
getter/setter pair
borderColor ↔ Color
getter/setter pair
borderWidth ↔ double
getter/setter pair
content ↔ String
getter/setter pairinherited
createDate → DateTime?
finalinherited
dashGap ↔ double
getter/setter pair
fillAlpha ↔ double
getter/setter pair
fillColor ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineHeadType ↔ CPDFLineType
getter/setter pair
lineTailType ↔ CPDFLineType
getter/setter pair
markState → CPDFAnnotationMarkState
finalinherited
page → int
finalinherited
points ↔ List<List<double>>?
getter/setter pair
rect → CPDFRectF
finalinherited
reviewState → CPDFAnnotationReviewState
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pairinherited
type → CPDFAnnotationType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited