CPDFMarkupAnnotation class annotations

Markup annotation model.

A text markup annotation (highlight/underline/strikeout/squiggly) that extends CPDFAnnotation.

Key properties:

Note: This class may represent different markup types via type (e.g. highlight/underline/strikeout/squiggly).

Serialization:

Inheritance

Constructors

CPDFMarkupAnnotation({required CPDFAnnotationType type, String title = "", required int page, String content = "", String uuid = '', DateTime? createDate, CPDFAnnotationMarkState markState = CPDFAnnotationMarkState.unmarked, CPDFAnnotationReviewState reviewState = CPDFAnnotationReviewState.none, required CPDFRectF rect, required String markedText, required Color color, double alpha = 255})
CPDFMarkupAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

alpha ↔ double
getter/setter pair
color ↔ Color
getter/setter pair
content ↔ String
getter/setter pairinherited
createDate → DateTime?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
markedText → String
final
markState → CPDFAnnotationMarkState
finalinherited
page → int
finalinherited
rect → CPDFRectF
finalinherited
reviewState → CPDFAnnotationReviewState
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pairinherited
type → CPDFAnnotationType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited