CPDFSignatureAnnotation class annotations

Signature annotation model.

An image-based signature annotation that extends CPDFAnnotation.

Key properties:

  • image: Base64-encoded image string for the signature appearance.

Serialization:

Inheritance

Constructors

CPDFSignatureAnnotation({String title = "", String content = "", DateTime? createDate, CPDFAnnotationMarkState markState = CPDFAnnotationMarkState.unmarked, CPDFAnnotationReviewState reviewState = CPDFAnnotationReviewState.none, required int page, String uuid = '', required CPDFRectF rect, String? image})
CPDFSignatureAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

content ↔ String
getter/setter pairinherited
createDate → DateTime?
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
image → String?
Base64 encoded image string representing the signature.
final
markState → CPDFAnnotationMarkState
finalinherited
page → int
finalinherited
rect → CPDFRectF
finalinherited
reviewState → CPDFAnnotationReviewState
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pairinherited
type → CPDFAnnotationType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited