CPDFTextAttribute class annotations

Text styling attributes used by text-based annotations.

This model is commonly referenced by annotations such as CPDFFreeTextAnnotation to describe text appearance.

Key properties:

Serialization:

Constructors

CPDFTextAttribute({required Color color, required String familyName, required String styleName, required double fontSize})
CPDFTextAttribute.fromJson(Map<String, dynamic> json)
factory

Properties

color ↔ Color
getter/setter pair
familyName ↔ String
getter/setter pair
fontSize ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleName ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited