CPDFTextStamp class annotations

Text stamp payload used by CPDFStampAnnotation when the stamp type is text.

A text stamp is rendered using content and date with a background shape and color.

Serialization:

Constructors

CPDFTextStamp({required String content, required String date, CPDFTextStampShape shape = CPDFTextStampShape.rect, CPDFTextStampColor color = CPDFTextStampColor.white})
const
CPDFTextStamp.fromJson(Map<String, dynamic> json)
factory

Properties

color → CPDFTextStampColor
final
content → String
final
date → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → CPDFTextStampShape
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited