CPDFCheckBoxWidget class forms

Checkbox form widget.

Extends CPDFWidget with checkbox-specific state and appearance.

Key properties:

Serialization:

Inheritance

Constructors

CPDFCheckBoxWidget({required String title, required int page, required CPDFRectF rect, required Color borderColor, required Color fillColor, String uuid = '', DateTime? createDate, double borderWidth = 2, bool isChecked = false, CPDFCheckStyle checkStyle = CPDFCheckStyle.check, required Color checkColor})
CPDFCheckBoxWidget.fromJson(Map<String, dynamic> json)
factory

Properties

borderColor ↔ Color
getter/setter pairinherited
borderWidth ↔ double
getter/setter pairinherited
checkColor ↔ Color
getter/setter pair
checkStyle ↔ CPDFCheckStyle
getter/setter pair
createDate → DateTime?
finalinherited
fillColor ↔ Color
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isChecked ↔ bool
getter/setter pair
page → int
finalinherited
rect → CPDFRectF
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pairinherited
type → CPDFFormType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited