CPDFComboBoxWidget class forms

Combo box form widget.

A drop-down selection form field that extends CPDFWidget.

Key properties:

Serialization:

Inheritance

Constructors

CPDFComboBoxWidget({required String title, required int page, required CPDFRectF rect, required Color borderColor, required Color fillColor, String uuid = '', DateTime? createDate, double borderWidth = 2, List<CPDFWidgetItem>? options, int selectItemAtIndex = 0, Color fontColor = Colors.black, double fontSize = 20, String familyName = 'Helvetica', String styleName = 'Regular'})
CPDFComboBoxWidget.fromJson(Map<String, dynamic> json)
factory

Properties

borderColor ↔ Color
getter/setter pairinherited
borderWidth ↔ double
getter/setter pairinherited
createDate → DateTime?
finalinherited
familyName ↔ String
getter/setter pair
fillColor ↔ Color
getter/setter pairinherited
fontColor ↔ Color
getter/setter pair
fontSize ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
options ↔ List<CPDFWidgetItem>?
getter/setter pair
page → int
finalinherited
rect → CPDFRectF
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectItemAtIndex ↔ int
getter/setter pair
styleName ↔ String
getter/setter pair
title ↔ String
getter/setter pairinherited
type → CPDFFormType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited