CPDFWidget class forms

Base model for a PDF form field (widget).

This model describes the common properties for all PDF form widgets and is used as the base data structure when reading/writing form field information.

Key properties:

Serialization:

Implementers

Constructors

CPDFWidget({required CPDFFormType type, required String title, required int page, required CPDFRectF rect, String uuid = '', DateTime? createDate, required Color borderColor, required Color fillColor, double borderWidth = 0})
CPDFWidget.fromJson(Map<String, dynamic> json)
factory

Properties

borderColor ↔ Color
getter/setter pair
borderWidth ↔ double
getter/setter pair
createDate → DateTime?
final
fillColor ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
page → int
final
rect → CPDFRectF
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair
type → CPDFFormType
final
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited