CPDFFreetextAttr class

Inheritance

Constructors

CPDFFreetextAttr({Color fontColor = Colors.black, double fontColorAlpha = 255, double fontSize = 30, CPDFAlignment? alignment = CPDFAlignment.left, String familyName = 'Helvetica', String styleName = ''})
const
CPDFFreetextAttr.fromJson(Map<String, dynamic> json)
factory

Properties

alignment CPDFAlignment?
Text alignment, CPDFAlignment.left aligned by default.
final
familyName String
final
fontColor Color
final
fontColorAlpha double
text color opacity. value range:0~255
final
fontSize double
font size, value range:1~100
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleName String
final
type String
no setteroverride

Methods

copyWith({Color? fontColor, double? fontColorAlpha, double? fontSize, CPDFAlignment? alignment, String? familyName, String? styleName}) CPDFFreetextAttr
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited