CPDFComboBoxAttr class
- Inheritance
-
- Object
- CPDFAnnotAttrBase
- CPDFListBoxAttr
- CPDFComboBoxAttr
Constructors
- CPDFComboBoxAttr({Color? fillColor = const Color(0xFFDDE9FF), Color? borderColor = const Color(0xFF1460F3), double? borderWidth = 2, Color? fontColor = Colors.black, double? fontSize = 20, String? familyName = 'Helvetica', String? styleName = ''})
-
const
-
CPDFComboBoxAttr.fromJson(Map<
String, dynamic> json) -
factory
Properties
- borderColor → Color?
-
The border color, the default is: Color(0xFF1460F3)
finalinherited
- borderWidth → double?
-
The border width, the default is: 2
border thickness, value range:0~10
finalinherited
- familyName → String?
-
finalinherited
- fillColor → Color?
-
finalinherited
- fontColor → Color?
-
The text color, the default is: Colors.black
finalinherited
- fontSize → double?
-
The font size, the default is: 20
value range:1~100
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleName → String?
-
finalinherited
- type → String
-
no setteroverride
Methods
-
copyWith(
{Color? fillColor, Color? borderColor, double? borderWidth, Color? fontColor, double? fontSize, String? familyName, String? styleName}) → CPDFComboBoxAttr -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited