CPDFPushButtonAttr class

Inheritance

Constructors

CPDFPushButtonAttr({String? title = 'Button', Color? fillColor = const Color(0xFFDDE9FF), Color? borderColor = const Color(0xFF1460F3), double? borderWidth = 2, Color? fontColor = Colors.black, double? fontSize = 20, String? familyName = 'Helvetica', String? styleName = ''})
const
CPDFPushButtonAttr.fromJson(Map<String, dynamic> json)
factory

Properties

borderColor → Color?
The border color, the default is: Color(0xFF1460F3)
final
borderWidth → double?
The border width, the default is: 2 border thickness, value range:0~10
final
familyName → String?
final
fillColor → Color?
final
fontColor → Color?
The text color, the default is: Colors.black
final
fontSize → double?
The font size, the default is: 20 value range:1~100
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleName → String?
final
title → String?
final
type → String
no setteroverride

Methods

copyWith({String? title, Color? fillColor, Color? borderColor, double? borderWidth, Color? fontColor, double? fontSize, String? familyName, String? styleName}) → CPDFPushButtonAttr
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited