CPDFBotaMenuItem<T> class

Constructors

CPDFBotaMenuItem({required T id, List<String> subMenus = const []})
const
CPDFBotaMenuItem.fromJson(Map<String, dynamic> json, T idParser(String))
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id → T
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited