CPDFUiBorderStyle class

Constructors

CPDFUiBorderStyle({Color? nodeColor = const Color(0xFF6499FF), Color borderColor = const Color(0xFF6499FF), double borderWidth = 2, List<double> borderDashPattern = const [10, 10]})
const
CPDFUiBorderStyle.fromJson(Map<String, dynamic> json)
factory

Properties

borderColor → Color
final
borderDashPattern → List<double>
final
borderWidth → double
final
hashCode → int
The hash code for this object.
no setterinherited
nodeColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited