CPDFUiStyleConfig class

Constructors

CPDFUiStyleConfig({String bookmarkIcon = "", CPDFUiStyleIcons icons = const CPDFUiStyleIcons(), Color selectTextColor = const Color(0x33000000), CPDFUiDisplayPageRectStyle displayPageRect = const CPDFUiDisplayPageRectStyle(), CPDFUiScreenshotStyle screenshot = const CPDFUiScreenshotStyle(), CPDFUiFormPreviewStyle formPreview = const CPDFUiFormPreviewStyle(), CPDFUiBorderStyle defaultBorderStyle = const CPDFUiBorderStyle(borderColor: Color(0xFF888888), borderWidth: 2, borderDashPattern: [10, 10]), CPDFUiBorderStyle focusBorderStyle = const CPDFUiBorderStyle(nodeColor: Color(0xFF6499FF), borderColor: Color(0xFF6499FF), borderWidth: 2, borderDashPattern: [10, 10]), CPDFUiBorderStyle cropImageStyle = const CPDFUiBorderStyle(borderColor: Color(0xFF6499FF), borderWidth: 5, borderDashPattern: [10, 10])})
const
CPDFUiStyleConfig.android({String bookmarkIcon = "", CPDFUiStyleIcons icons = const CPDFUiStyleIcons(), Color selectTextColor = const Color(0x33000000), CPDFUiDisplayPageRectStyle displayPageRect = const CPDFUiDisplayPageRectStyle(), CPDFUiScreenshotStyle screenshot = const CPDFUiScreenshotStyle(borderWidth: 5, borderDashPattern: [30, 8]), CPDFUiFormPreviewStyle formPreview = const CPDFUiFormPreviewStyle(), CPDFUiBorderStyle defaultBorderStyle = const CPDFUiBorderStyle(borderColor: Color(0xFF888888), borderWidth: 2, borderDashPattern: [20, 10]), CPDFUiBorderStyle focusBorderStyle = const CPDFUiBorderStyle(nodeColor: Color(0xFF6499FF), borderColor: Color(0xFF6499FF), borderWidth: 2, borderDashPattern: [20, 10]), CPDFUiBorderStyle cropImageStyle = const CPDFUiBorderStyle(borderColor: Color(0xFF6499FF), borderWidth: 2, borderDashPattern: [20, 10])})
const
CPDFUiStyleConfig.create({String? bookmarkIcon, CPDFUiStyleIcons? icons, Color? selectTextColor, CPDFUiDisplayPageRectStyle? displayPageRect, CPDFUiScreenshotStyle? screenshot, CPDFUiFormPreviewStyle? formPreview, CPDFUiBorderStyle? defaultBorderStyle, CPDFUiBorderStyle? focusBorderStyle, CPDFUiBorderStyle? cropImageStyle})
factory
CPDFUiStyleConfig.fromJson(Map<String, dynamic> json)
factory
CPDFUiStyleConfig.ios({String bookmarkIcon = "", CPDFUiStyleIcons icons = const CPDFUiStyleIcons(), Color selectTextColor = const Color(0x33000000), CPDFUiDisplayPageRectStyle displayPageRect = const CPDFUiDisplayPageRectStyle(), CPDFUiScreenshotStyle screenshot = const CPDFUiScreenshotStyle(), CPDFUiFormPreviewStyle formPreview = const CPDFUiFormPreviewStyle(), CPDFUiBorderStyle defaultBorderStyle = const CPDFUiBorderStyle(borderColor: Color(0xFF888888), borderWidth: 1, borderDashPattern: [10, 4]), CPDFUiBorderStyle focusBorderStyle = const CPDFUiBorderStyle(nodeColor: Color(0xFF6499FF), borderColor: Color(0xFF6499FF), borderWidth: 1, borderDashPattern: [10, 4]), CPDFUiBorderStyle cropImageStyle = const CPDFUiBorderStyle(borderColor: Color(0xFF6499FF), borderWidth: 2, borderDashPattern: [10, 4])})
const

Properties

bookmarkIcon → String
final
cropImageStyle → CPDFUiBorderStyle
final
defaultBorderStyle → CPDFUiBorderStyle
final
displayPageRect → CPDFUiDisplayPageRectStyle
final
focusBorderStyle → CPDFUiBorderStyle
final
formPreview → CPDFUiFormPreviewStyle
final
hashCode → int
The hash code for this object.
no setterinherited
icons → CPDFUiStyleIcons
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenshot → CPDFUiScreenshotStyle
final
selectTextColor → Color
final

Methods

copyWith({String? bookmarkIcon, CPDFUiStyleIcons? icons, Color? selectTextColor, CPDFUiDisplayPageRectStyle? displayPageRect, CPDFUiScreenshotStyle? screenshot, CPDFUiFormPreviewStyle? formPreview, CPDFUiBorderStyle? defaultBorderStyle, CPDFUiBorderStyle? focusBorderStyle, CPDFUiBorderStyle? cropImageStyle}) → CPDFUiStyleConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited