CPDFUiStyleIcons class
Constructors
- CPDFUiStyleIcons({String selectTextLeftIcon = "", String selectTextRightIcon = "", String selectTextIcon = "", String rotationAnnotationIcon = ""})
-
const
-
CPDFUiStyleIcons.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rotationAnnotationIcon → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectTextIcon → String
-
final
- selectTextLeftIcon → String
-
final
- selectTextRightIcon → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited