CPDFContextMenuConfig class

Constructors

CPDFContextMenuConfig({Color? backgroundColor, double fontSize = 14.0, List<double> padding = const [0, 0, 0, 0], double iconSize = 36, CPDFGlobalContextMenu global = const CPDFGlobalContextMenu(), CPDFViewModeContextMenu viewMode = const CPDFViewModeContextMenu(), CPDFAnnotationModeContextMenu annotationMode = const CPDFAnnotationModeContextMenu(), CPDFContentEditorModeContextMenu contentEditorMode = const CPDFContentEditorModeContextMenu(), CPDFFormModeContextMenu formMode = const CPDFFormModeContextMenu()})
const

Properties

annotationMode → CPDFAnnotationModeContextMenu
final
backgroundColor → Color?
final
contentEditorMode → CPDFContentEditorModeContextMenu
final
fontSize → double
final
formMode → CPDFFormModeContextMenu
final
global → CPDFGlobalContextMenu
final
hashCode → int
The hash code for this object.
no setterinherited
iconSize → double
final
padding → List<double>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewMode → CPDFViewModeContextMenu
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited