CPDFGlobalContextMenu class

Constructors

CPDFGlobalContextMenu({List<CPDFContextMenuItem<CPDFScreenShotMenuKey>> screenshot = const [CPDFContextMenuItem(CPDFScreenShotMenuKey.exit), CPDFContextMenuItem(CPDFScreenShotMenuKey.share)]})
const
CPDFGlobalContextMenu.screenshotOnly(List<CPDFScreenShotMenuKey> keys)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenshot → List<CPDFContextMenuItem<CPDFScreenShotMenuKey>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited