interceptNoteAction property

bool interceptNoteAction
final

Intercept click actions on existing note annotations. Default is false (not intercepted). Clicking a note annotation will directly pop up the note content editing dialog. When set to true, the click event is intercepted via CPDFReaderWidget.onInterceptAnnotationActionCallback. Developers can handle custom note content editing dialogs through the callback.

Implementation

final bool interceptNoteAction;