CPDFConfiguration class configuration

modeConfig: Configuration of parameters that can be adjusted when opening a PDF interface. For example, setting the default display mode when opening, such as entering viewer or annotations mode.

toolbarConfig: Configuration of top toolbar functionality and menu feature lists. This allows you to customize the buttons and menu options on the top toolbar for various operations.

readerViewConfig: Configuration related to the PDF view, including functions like highlighting hyperlinks and form field highlighting.

ComPDFKit.openDocument(
  tempDocumentPath,
  password: '',
  configuration: CPDFConfiguration());

Constructors

CPDFConfiguration({CPDFModeConfig modeConfig = const CPDFModeConfig(initialViewMode: CPDFViewMode.viewer), CPDFToolbarConfig? toolbarConfig, CPDFReaderViewConfig? readerViewConfig, CPDFAnnotationsConfig annotationsConfig = const CPDFAnnotationsConfig(), CPDFContentEditorConfig contentEditorConfig = const CPDFContentEditorConfig(), CPDFFormsConfig formsConfig = const CPDFFormsConfig(), CPDFGlobalConfig globalConfig = const CPDFGlobalConfig(), CPDFContextMenuConfig contextMenuConfig = const CPDFContextMenuConfig()})

Properties

annotationsConfig ↔ CPDFAnnotationsConfig
getter/setter pair
contentEditorConfig ↔ CPDFContentEditorConfig
getter/setter pair
contextMenuConfig ↔ CPDFContextMenuConfig
getter/setter pair
formsConfig ↔ CPDFFormsConfig
getter/setter pair
globalConfig ↔ CPDFGlobalConfig
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modeConfig ↔ CPDFModeConfig
getter/setter pair
readerViewConfig ↔ CPDFReaderViewConfig
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolbarConfig ↔ CPDFToolbarConfig
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited