CPDFFormAttribute class

Constructors

CPDFFormAttribute({CPDFTextFieldAttr textFieldAttr = const CPDFTextFieldAttr(), CPDFCheckBoxAttr checkBoxAttr = const CPDFCheckBoxAttr(), CPDFRadioButtonAttr radioButtonAttr = const CPDFRadioButtonAttr(), CPDFListBoxAttr listBoxAttr = const CPDFListBoxAttr(), CPDFComboBoxAttr comboBoxAttr = const CPDFComboBoxAttr(), CPDFPushButtonAttr pushButtonAttr = const CPDFPushButtonAttr(), CPDFSignatureWidgetAttr signaturesFieldsAttr = const CPDFSignatureWidgetAttr()})
const
CPDFFormAttribute.fromJson(Map<String, dynamic> json)
factory

Properties

checkBoxAttr → CPDFCheckBoxAttr
final
comboBoxAttr → CPDFComboBoxAttr
final
hashCode → int
The hash code for this object.
no setterinherited
listBoxAttr → CPDFListBoxAttr
final
pushButtonAttr → CPDFPushButtonAttr
final
radioButtonAttr → CPDFRadioButtonAttr
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signaturesFieldsAttr → CPDFSignatureWidgetAttr
final
textFieldAttr → CPDFTextFieldAttr
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited