CPDFFormsConfig class

Constructors

CPDFFormsConfig({List<CPDFFormType> availableTypes = CPDFFormType.values, List<CPDFConfigTool> availableTools = const [CPDFConfigTool.undo, CPDFConfigTool.redo], CPDFFormAttribute initAttribute = const CPDFFormAttribute(), bool showCreateListBoxOptionsDialog = true, bool showCreateComboBoxOptionsDialog = true, bool showCreatePushButtonOptionsDialog = true, bool interceptAllFormWidgetActions = false, List<CPDFFormType> interceptFormWidgetActions = const []})
const

Properties

availableTools → List<CPDFConfigTool>
Only supports CPDFConfigTool.undo and CPDFConfigTool.redo.
final
availableTypes → List<CPDFFormType>
In CPDFViewMode.forms mode, the list of form types at the bottom of the view.
final
hashCode → int
The hash code for this object.
no setterinherited
initAttribute → CPDFFormAttribute
Form default attribute configuration
final
interceptAllFormWidgetActions → bool
Intercept all form widget click actions.
final
interceptFormWidgetActions → List<CPDFFormType>
Form widget types whose click actions should be intercepted.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showCreateComboBoxOptionsDialog → bool
final
showCreateListBoxOptionsDialog → bool
final
showCreatePushButtonOptionsDialog → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited