interceptComboBoxAction property

bool interceptComboBoxAction
final

Intercept combo box click event. Default is false (not intercepted), clicking the combo box directly shows the combo box options dialog. When set to true, the click event is intercepted via CPDFReaderWidget.onInterceptWidgetActionCallback. Developers can handle displaying a custom combo box options dialog via the callback. Note: only support android platform in version 2.6.2

Implementation

final bool interceptComboBoxAction;