interceptListBoxAction property
Intercept list box click event. Default is false (not intercepted), clicking the list box directly shows the list box options dialog. When set to true, the click event is intercepted via CPDFReaderWidget.onInterceptWidgetActionCallback. Developers can handle displaying a custom list box options dialog via the callback. Note: only support android platform in version 2.6.2
Implementation
final bool interceptListBoxAction;