interceptPushButtonAction property

bool interceptPushButtonAction
final

Intercept button click event. Default is false (not intercepted), clicking the button directly triggers the button action. When set to true, the click event is intercepted via CPDFReaderWidget.onInterceptWidgetActionCallback. Developers can handle button click actions via the callback. Note: only support android platform in version 2.6.2

Implementation

final bool interceptPushButtonAction;