CPDFGlobalConfig class

Constructors

CPDFGlobalConfig({CPDFThemeMode themeMode = CPDFThemeMode.system, bool fileSaveExtraFontSubset = true, bool useSaveIncremental = true, CPDFWatermarkConfig watermark = const CPDFWatermarkConfig(), bool enableExitSaveTips = true, CPDFFillSignatureType signatureType = CPDFFillSignatureType.manual, CPDFThumbnailConfig thumbnail = const CPDFThumbnailConfig(), bool enableErrorTips = true, CPDFBotaConfig bota = const CPDFBotaConfig(), CPDFSearchConfig search = const CPDFSearchConfig(), CPDFPageEditorConfig pageEditor = const CPDFPageEditorConfig(), List<CPDFPencilMenus> pencilMenus = CPDFPencilMenus.values})
const

Properties

bota → CPDFBotaConfig
final
enableErrorTips → bool
final
enableExitSaveTips → bool
final
fileSaveExtraFontSubset → bool
In version V2.1.0, you can set whether to save a subset of fonts when the document is saved. The default value is true. Saving font subsets may increase file size.
final
hashCode → int
The hash code for this object.
no setterinherited
pageEditor → CPDFPageEditorConfig
final
pencilMenus → List<CPDFPencilMenus>
ios pencil annotation menus config Only supports iOS platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
signatureType → CPDFFillSignatureType
final
themeMode → CPDFThemeMode
Only supports Android platform in version 2.0.2
final
thumbnail → CPDFThumbnailConfig
final
useSaveIncremental → bool
Whether to use incremental save. Default is true. Enabling incremental save can improve save speed and reduce memory usage, but may increase file size. If you need to generate a smaller file, set this option to false for a full save. This affects all save operations in CPDFReaderWidget, including manual and auto-save, such as saving, sharing, and saving on exit. Only supported on Android platform.
final
watermark → CPDFWatermarkConfig
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited