CPDFModeConfig class

Constructors

CPDFModeConfig({CPDFViewMode initialViewMode = CPDFViewMode.viewer, CPDFUIVisibilityMode uiVisibilityMode = CPDFUIVisibilityMode.automatic, List<CPDFViewMode> availableViewModes = CPDFViewMode.values})
const

Properties

availableViewModes → List<CPDFViewMode>
Configure supported modes
final
hashCode → int
The hash code for this object.
no setterinherited
initialViewMode → CPDFViewMode
Default mode to display when opening the PDF View, default is CPDFViewMode.viewer
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiVisibilityMode → CPDFUIVisibilityMode
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited