CPDFReaderViewConfig class

pdf readerView configuration

Constructors

CPDFReaderViewConfig({bool linkHighlight = true, bool formFieldHighlight = true, CPDFDisplayMode displayMode = CPDFDisplayMode.singlePage, bool continueMode = true, bool verticalMode = true, bool cropMode = false, CPDFThemes themes = CPDFThemes.light, bool enableSliderBar = true, bool enablePageIndicator = true, int pageSpacing = 10, double pageScale = 1.0, bool pageSameWidth = true, List<int> margins = const [0, 0, 0, 0], bool enableMinScale = true, bool annotationsVisible = true, bool enableCreateEditTextInput = true, bool enableCreateImagePickerDialog = true, bool enableDoubleTapZoom = false, CPDFAccessibilityConfig accessibilityConfig = const CPDFAccessibilityConfig(), CPDFUiStyleConfig? uiStyle})

Properties

accessibilityConfig → CPDFAccessibilityConfig
Accessibility configuration for keyboard navigation and TalkBack.
final
annotationsVisible → bool
Whether to display the annotation layer. Default: true
final
continueMode → bool
Whether PDF page flipping is continuous scrolling.
final
cropMode → bool
Cropping mode.
final
displayMode → CPDFDisplayMode
Display mode of the PDF document, single page, double page, or book mode. Default: CPDFDisplayMode.singlePage
final
enableCreateEditTextInput → bool
In content editing mode, when only text editing is selected, whether to enable creating a text input box by clicking the page area. Default value: true
final
enableCreateImagePickerDialog → bool
In content editing mode, when only image editing is selected, whether to enable creating an image picker dialog by clicking the page area. Default value: true
final
enableDoubleTapZoom → bool
Whether to enable double-tap zooming functionality. Default value: true
final
enableMinScale → bool
final
enablePageIndicator → bool
Whether to display the bottom page indicator.
final
enableSliderBar → bool
Whether to display the sidebar quick scroll bar.
final
formFieldHighlight → bool
final
hashCode → int
The hash code for this object.
no setterinherited
linkHighlight → bool
final
margins → List<int>
final
pageSameWidth → bool
only android platform
final
pageScale → double
Page scale value, default 1.0.
final
pageSpacing → int
Spacing between each page of the PDF, default 10px.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themes → CPDFThemes
Theme color.
final
uiStyle → CPDFUiStyleConfig
UI style configuration, such as setting border styles for selected annotations, forms, and content editing text. Default: CPDFUiStyleConfig()
final
verticalMode → bool
Whether scrolling is in vertical direction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited