CPDFAnnotationRenderOptions class

Constructors

CPDFAnnotationRenderOptions({double scale = 3.0, int? targetWidth, int? targetHeight, CPDFPageCompression compression = CPDFPageCompression.png, int quality = 100})
const

Properties

compression → CPDFPageCompression
final
hashCode → int
The hash code for this object.
no setterinherited
quality → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final
targetHeight → int?
final
targetWidth → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited