CPDFStandardStamp enum

Inheritance
Available extensions

Values

notApproved → const CPDFStandardStamp
approved → const CPDFStandardStamp
completed → const CPDFStandardStamp
final_ → const CPDFStandardStamp
draft → const CPDFStandardStamp
confidential → const CPDFStandardStamp
notForPublicRelease → const CPDFStandardStamp
forPublicRelease → const CPDFStandardStamp
forComment → const CPDFStandardStamp
void_ → const CPDFStandardStamp
preliminaryResults → const CPDFStandardStamp
informationOnly → const CPDFStandardStamp
accepted → const CPDFStandardStamp
rejected → const CPDFStandardStamp
witness → const CPDFStandardStamp
initialHere → const CPDFStandardStamp
signHere → const CPDFStandardStamp
revised → const CPDFStandardStamp
privateAccepted → const CPDFStandardStamp
privateRejected → const CPDFStandardStamp
privateRadioMark → const CPDFStandardStamp
unknown → const CPDFStandardStamp

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on CPDFStandardStamp, provided by the CPDFStampExtension extension

no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CPDFStandardStamp>
A constant List of the values in this enum, in order of their declaration.