CPDFThemes class

Constructors

CPDFThemes.custom(Color customColor)
factory

Properties

color → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CPDFThemeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(Color color) → CPDFThemes

Constants

dark → const CPDFThemes
light → const CPDFThemes
reseda → const CPDFThemes
sepia → const CPDFThemes