CPDFUriAction class

A class representing a URI action in a PDF document. This action opens a specified URI when triggered. It extends the CPDFAction class. The uri property holds the URI to be opened. Example usage:

// Create a URI action
CPDFUriAction action = CPDFUriAction(uri: "https://www.compdf.com/");

// Create to email action
CPDFUriAction emailAction = CPDFUriAction(url: "mailto:support@compdf.com");

See also:

Inheritance

Constructors

CPDFUriAction({required String uri})
CPDFUriAction.email({required String email})
CPDFUriAction.fromJson(Map<String, dynamic> json)
factory
CPDFUriAction.url({required String url})

Properties

actionType CPDFActionType
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited