CPDFBookmark class

Constructors

CPDFBookmark({required String title, required int pageIndex, DateTime? date, String uuid = ''})
CPDFBookmark.fromJson(Map<String, dynamic> json)
factory

Properties

date → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
pageIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String
getter/setter pair
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited