CPDFDestination class

Constructors

CPDFDestination({required int pageIndex, double zoom = 0.0, double positionX = 0.0, double positionY = 0.0})
const
CPDFDestination.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageIndex → int
final
positionX → double
final
positionY → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoom → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited