CPDFExtractImageResult class

Result of extracting images from a PDF document.

Constructors

CPDFExtractImageResult({required bool success, required int count, required String directoryPath, required List<String> imagePaths})
Creates an image extraction result.
const
CPDFExtractImageResult.fromJson(Map<String, dynamic> json)
Creates an image extraction result from native JSON data.
factory

Properties

count → int
Number of image files found in directoryPath after extraction.
final
directoryPath → String
Directory where images were written.
final
hashCode → int
The hash code for this object.
no setterinherited
imagePaths → List<String>
Full paths of image files found in directoryPath after extraction.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
Whether the native extraction call completed successfully.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited