CPDFDocumentPermissionInfo class

Constructors

CPDFDocumentPermissionInfo({required bool allowsPrinting, required bool allowsHighQualityPrinting, required bool allowsCopying, required bool allowsDocumentChanges, required bool allowsDocumentAssembly, required bool allowsCommenting, required bool allowsFormFieldEntry})
const
CPDFDocumentPermissionInfo.empty()
CPDFDocumentPermissionInfo.fromJson(Map<String, dynamic> json)
factory

Properties

allowsCommenting → bool
Create or modify annotations, including form field entries
final
allowsCopying → bool
Extract content (text, images, etc.)
final
allowsDocumentAssembly → bool
Page management: insert, delete, and rotate pages
final
allowsDocumentChanges → bool
Modify the document contents except for page management (document attributes)
final
allowsFormFieldEntry → bool
Modify form field entries, even if allowsCommenting is false
final
allowsHighQualityPrinting → bool
final
allowsPrinting → bool
Printing the document
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited