CPDFInfo class

Constructors

CPDFInfo({required String title, required String author, required String subject, required String keywords, required String creator, required String producer, DateTime? creationDate, DateTime? modificationDate})
CPDFInfo.empty()
CPDFInfo.fromJson(Map<String, dynamic> json)
factory

Properties

author → String
final
creationDate → DateTime?
final
creator → String
final
hashCode → int
The hash code for this object.
no setterinherited
keywords → String
final
modificationDate → DateTime?
final
producer → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited