CPDFOutline class

Constructors

CPDFOutline({required String uuid, String? tag = '', required String title, required int level, CPDFDestination? destination, List<CPDFOutline> childList = const [], CPDFAction? action})
CPDFOutline.fromJson(Map<String, dynamic> json)
factory

Properties

action ↔ CPDFAction?
getter/setter pair
childList ↔ List<CPDFOutline>
getter/setter pair
destination ↔ CPDFDestination?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
level ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String?
getter/setter pair
title ↔ String
getter/setter pair
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited