imagePath property
Image path for image-type watermark.
When read from a document, this is non-empty only if image export was requested and succeeded.
Implementation
final String imagePath;
Image path for image-type watermark.
When read from a document, this is non-empty only if image export was requested and succeeded.
final String imagePath;