CPDFEditArea class

Represents an editable area in a PDF document. Contains the type of the area, a unique identifier (UUID), and the page number.

Implementers

Constructors

CPDFEditArea({required CPDFEditAreaType type, required String uuid, required int page})
const
CPDFEditArea.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
page → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CPDFEditAreaType
final
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited