CPDFEditImageArea class

Inheritance

Constructors

CPDFEditImageArea({required String uuid, required int page, double alpha = 255, Uint8List? image})
CPDFEditImageArea.fromJson(Map<String, dynamic> json)
factory

Properties

alpha → double
final
hashCode → int
The hash code for this object.
no setterinherited
image → Uint8List?
final
page → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CPDFEditAreaType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited