CPDFEditTextArea class

Inheritance

Constructors

CPDFEditTextArea({required String uuid, required int page, String text = '', CPDFAlignment alignment = CPDFAlignment.left, double fontSize = 12.0, Color color = Colors.black, double alpha = 255, String familyName = 'Helvetica', String styleName = 'Regular'})
const
CPDFEditTextArea.fromJson(Map<String, dynamic> json)
factory

Properties

alignment → CPDFAlignment
final
alpha → double
final
color → Color
final
familyName → String
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
page → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleName → String
final
text → String
final
type → CPDFEditAreaType
finalinherited
uuid → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited