CPDFSearchOptions enum

Search options for PDF text search.

Inheritance
Available extensions

Values

caseInsensitive → const CPDFSearchOptions

Case-insensitive search.

const CPDFSearchOptions(0)
caseSensitive → const CPDFSearchOptions

Case sensitive search.

const CPDFSearchOptions(1)
matchWholeWord → const CPDFSearchOptions

Matches a whole word

const CPDFSearchOptions(2)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nativeValue → int
Native value used by the platform code.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CPDFSearchOptions>
A constant List of the values in this enum, in order of their declaration.