CPDFTextRange class

Available extensions

Constructors

CPDFTextRange({required int pageIndex, required int location, required int length, int textRangeIndex = 0})
const
CPDFTextRange.fromJson(Map<String, dynamic> map)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
final
location → int
final
pageIndex → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textRangeIndex → int
final

Methods

expanded({int before = 0, int after = 0}) → CPDFTextRange

Available on CPDFTextRange, provided by the CPDFTextRangeExtension extension

Returns a new CPDFTextRange that expands the current range by the given number of characters before and after the original range.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited