CPDFPageThumbnailKey class

Immutable key used by CPDFPageThumbnailProvider.

Constructors

CPDFPageThumbnailKey({required CPDFPageThumbnailSource source, required String sourceScope, required int pageIndex, required int width, required int height, required int rotation, required CPDFPageThumbnailOptions options})
Creates a thumbnail key.
const

Properties

cacheKey → String
String used by in-flight maps and disk cache files.
no setter
diskDirectoryName → String
Hashed directory name used by disk cache.
no setter
diskFileName → String
Hashed file name used by disk cache.
no setter
hashCode → int
The hash code for this object.
no setteroverride
height → int
Render height in pixels.
final
options → CPDFPageThumbnailOptions
Render options.
final
pageIndex → int
Page index.
final
rotation → int
Page rotation in degrees.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → CPDFPageThumbnailSource
Original source.
final
sourceScope → String
Cache scope derived from file timestamp or document cache version.
final
width → int
Render width in pixels.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override