CPDFPageThumbnailProvider class

Image provider that renders one PDF page as a thumbnail.

Inheritance

Constructors

CPDFPageThumbnailProvider({required CPDFPageThumbnailSource source, required int pageIndex, CPDFPageThumbnailOptions options = const CPDFPageThumbnailOptions(), CPDFPageThumbnailService? service, bool useFlutterImageCache = true})
Creates a thumbnail provider.
const
CPDFPageThumbnailProvider.document({required CPDFDocument document, required int pageIndex, CPDFPageThumbnailOptions options = const CPDFPageThumbnailOptions(), Object? cacheVersion, CPDFPageThumbnailService? service, bool useFlutterImageCache = true})
Creates a thumbnail provider from an existing document.
CPDFPageThumbnailProvider.file({required String filePath, required int pageIndex, String password = '', CPDFPageThumbnailOptions options = const CPDFPageThumbnailOptions(), CPDFPageThumbnailService? service, bool useFlutterImageCache = true})
Creates a thumbnail provider from a file path.

Properties

hashCode int
The hash code for this object.
no setterinherited
options CPDFPageThumbnailOptions
Render options.
final
pageIndex int
Page index to render.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service CPDFPageThumbnailService?
Service used to load thumbnails.
final
source CPDFPageThumbnailSource
Thumbnail source.
final
useFlutterImageCache bool
Whether Flutter's decoded image cache is used before SDK caches.
final

Methods

createStream(ImageConfiguration configuration) ImageStream
Called by resolve to create the ImageStream it returns.
inherited
evict({ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) Future<bool>
Evicts an entry from the image cache.
inherited
evictThumbnail({ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) Future<bool>
Evicts this thumbnail from Flutter image cache and SDK disk cache.
loadBuffer(CPDFPageThumbnailKey key, DecoderBufferCallback decode) ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
inherited
loadImage(CPDFPageThumbnailKey key, ImageDecoderCallback decode) ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obtainCacheStatus({required ImageConfiguration configuration, ImageErrorListener? handleError}) Future<ImageCacheStatus?>
Returns the cache location for the key that this ImageProvider creates.
inherited
obtainKey(ImageConfiguration configuration) Future<CPDFPageThumbnailKey>
Converts an ImageProvider's settings plus an ImageConfiguration to a key that describes the precise image to load.
override
resolve(ImageConfiguration configuration) ImageStream
Resolves this image provider using the given configuration, returning an ImageStream.
inherited
resolveStreamForKey(ImageConfiguration configuration, ImageStream stream, CPDFPageThumbnailKey key, ImageErrorListener handleError) → void
Called by resolve with the key returned by obtainKey.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited