CPDFPageThumbnailRenderer class abstract

Renders encoded thumbnail bytes.

Implementers

Constructors

CPDFPageThumbnailRenderer()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPageMetrics(CPDFPageThumbnailSource source, int pageIndex) Future<CPDFPageThumbnailPageMetrics>
Returns the page metrics for source.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(CPDFPageThumbnailKey key) Future<Uint8List>
Renders key to encoded image bytes.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited