CPDFRectF class util

A rectangle defined by left, top, right, and bottom coordinates.

Constructors

CPDFRectF({required double left, required double top, required double right, required double bottom})
const
CPDFRectF.fromJson(Map<String, dynamic> json)
factory
CPDFRectF.fromLTRB(double left, double top, double right, double bottom)
factory
CPDFRectF.isEmpty()
const

Properties

bottom → double
final
hashCode → int
The hash code for this object.
no setterinherited
left → double
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
no setter
top → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited