CPDFReaderSliderBar class viewer-ui

Quick swipe bar control for CPDFReaderWidget

version: v1.1 example:

// vertical scroll
CPDFReaderSliderBar(
    thumbColor: Colors.green,
    showPageIndicator: false,
    currentPage: _currentPage,
    pageCount: _pageCount,
    axis: Axis.vertical,
    onJumpToPage: (page) {
    _controller?.setDisplayPageIndex(page);
    setState(() => _currentPage = page);
    }
)

// horizontal scroll
CPDFReaderSliderBar(
    thumbColor: Colors.green,
    showPageIndicator: false,
    currentPage: _currentPage,
    pageCount: _pageCount,
    axis: Axis.horizontal,
    onJumpToPage: (page) {
    _controller?.setDisplayPageIndex(page);
    setState(() => _currentPage = page);
    }
)
Inheritance

Constructors

CPDFReaderSliderBar({Key? key, required int currentPage, required int pageCount, required void onJumpToPage(int page, bool isFinal), double thumbHeight = 40.0, bool showPageIndicator = true, Widget thumbBuilder(bool isDragging)?, Axis axis = Axis.vertical, Color thumbColor = Colors.blue})
const

Properties

axis → Axis
final
currentPage → int
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onJumpToPage → void Function(int page, bool isFinal)
final
pageCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showPageIndicator → bool
final
thumbBuilder → Widget Function(bool isDragging)?
final
thumbColor → Color
final
thumbHeight → double
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<CPDFReaderSliderBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited