widgets/cpdf_reader_widget library
Classes
- CPDFReaderWidget viewer-ui
- PDF reader widget for viewing and interacting with documents.
Typedefs
- CPDFDocumentIsReadyCallback = void Function()
- Called when the native document is ready.
- CPDFDocumentSaveCallback = void Function()
- Called when the document is saved.
- CPDFFillScreenChangedCallback = void Function(bool isFillScreen)
- Called when fill-screen mode changes.
- CPDFIOSClickBackPressedCallback = void Function()
- Called when the iOS back button is pressed.
- CPDFOnAnnotationCreationPreparedCallback = void Function(CPDFAnnotationType type, CPDFAnnotation? annotation)
- Called when annotation creation is prepared on the native side.
- CPDFOnCustomContextMenuItemTappedCallback = void Function(String identifier, dynamic event)
- Callback triggered when a custom context menu item is tapped.
- CPDFOnCustomToolbarItemTappedCallback = void Function(String identifier)
- Called when a custom toolbar item is tapped.
- CPDFOnEventsCallback = void Function(Object? data)
- Called when native side emits a custom event payload.
- CPDFOnInterceptAnnotationActionCallback = void Function(CPDFAnnotation annotation)
- Callback for intercepting annotation actions (note and hyperlink annotations).
- CPDFOnInterceptWidgetActionCallback = void Function(CPDFWidget widget)
- Callback for intercepting widget actions (list box, combo box, etc.). Used to configure interception of form field widget actions in CPDFConfiguration, and dispatch the events to the Flutter side for handling.
- CPDFOnTapMainDocAreaCallback = void Function()
- Called when the main document area is tapped.
- CPDFPageChangedCallback = void Function(int pageIndex)
- Called when the current visible page changes.
- CPDFPageEditDialogBackPressCallback = void Function()
- Called when user presses back in page edit dialog.
- CPDFReaderWidgetCreatedCallback = void Function(CPDFReaderWidgetController controller) viewer-ui
- Called when the CPDFReaderWidgetController is ready.