CPDFReplyAnnotation class annotations

A reply attached to a PDF annotation.

Reply annotations expose the common annotation fields such as uuid, page, title, content, createDate, modifyDate, rect, markState, and reviewState.

Inheritance

Constructors

CPDFReplyAnnotation({CPDFAnnotationType type = CPDFAnnotationType.unknown, String title = '', required int page, String content = '', required String uuid, DateTime? createDate, DateTime? modifyDate, CPDFAnnotationMarkState markState = CPDFAnnotationMarkState.unmarked, CPDFAnnotationReviewState reviewState = CPDFAnnotationReviewState.none, required CPDFRectF rect})
CPDFReplyAnnotation.fromJson(Map<String, dynamic> json)
factory

Properties

content String
getter/setter pairinherited
createDate DateTime?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
markState CPDFAnnotationMarkState
finalinherited
modifyDate DateTime?
The last modified time of this reply, if provided by the native SDK.
final
page int
finalinherited
rect CPDFRectF
finalinherited
reviewState CPDFAnnotationReviewState
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pairinherited
type CPDFAnnotationType
finalinherited
uuid String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited