CPDFSignatureWidget class forms
Signature form widget.
A signature field placeholder that extends CPDFWidget.
Serialization:
- Use CPDFSignatureWidget.fromJson to create an instance from a JSON map.
- Use toJson inherited from CPDFWidget to convert this instance to JSON.
- Inheritance
-
- Object
- CPDFWidget
- CPDFSignatureWidget
Constructors
Properties
- borderColor ↔ Color
-
getter/setter pairinherited
- borderWidth ↔ double
-
getter/setter pairinherited
- createDate → DateTime?
-
finalinherited
- fillColor ↔ Color
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- page → int
-
finalinherited
- rect → CPDFRectF
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String
-
getter/setter pairinherited
- type → CPDFFormType
-
finalinherited
- uuid → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited