CPDFSignatureWidgetAttr class
- Inheritance
-
- Object
- CPDFAnnotAttrBase
- CPDFSignatureWidgetAttr
Constructors
- CPDFSignatureWidgetAttr({Color? fillColor = const Color(0xFFDDE9FF), Color? borderColor = const Color(0xFF1460F3), double? borderWidth = 2})
-
const
-
CPDFSignatureWidgetAttr.fromJson(Map<
String, dynamic> json) -
factory
Properties
- borderColor → Color?
-
final
- borderWidth → double?
-
final
- fillColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
no setteroverride
Methods
-
copyWith(
{Color? fillColor, Color? borderColor, double? borderWidth}) → CPDFSignatureWidgetAttr -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited