CPDFAccessibilityConfig class

Accessibility configuration for the PDF reader view.

Since v3.0.0, this configuration is currently only supported on Android.

Constructors

CPDFAccessibilityConfig({bool keyboardNavigationEnabled = false, bool talkBackEnabled = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keyboardNavigationEnabled bool
Whether hardware keyboard navigation is enabled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
talkBackEnabled bool
Whether TalkBack support is enabled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited