autoShowNoteEditDialog property
In annotation mode, when tapping the PDF page after selecting
CPDFAnnotationType.note, whether to automatically show the default note
edit dialog.
Default: true. If set to false, the default note edit dialog will not be
displayed. You can handle note content editing yourself via the
CPDFReaderWidget(onAnnotationCreationPreparedCallback: ...) callback,
then call controller.document.updateAnnotation(annotation) to save the
custom content or controller.document.removeAnnotation(annotation) to
cancel the created note.
Implementation
final bool autoShowNoteEditDialog;