CPDFFormsConfig class

Constructors

CPDFFormsConfig({List<CPDFFormType> availableTypes = CPDFFormType.values, List<CPDFConfigTool> availableTools = const [CPDFConfigTool.undo, CPDFConfigTool.redo], CPDFFormAttribute initAttribute = const CPDFFormAttribute(), bool showCreateListBoxOptionsDialog = true, bool showCreateComboBoxOptionsDialog = true, bool showCreatePushButtonOptionsDialog = true, bool interceptListBoxAction = false, bool interceptComboBoxAction = false, bool interceptPushButtonAction = false})
const

Properties

availableTools List<CPDFConfigTool>
Only supports CPDFConfigTool.undo and CPDFConfigTool.redo.
final
availableTypes List<CPDFFormType>
In CPDFViewMode.forms mode, the list of form types at the bottom of the view.
final
hashCode int
The hash code for this object.
no setterinherited
initAttribute CPDFFormAttribute
Form default attribute configuration
final
interceptComboBoxAction bool
Intercept combo box click event. Default is false (not intercepted), clicking the combo box directly shows the combo box options dialog. When set to true, the click event is intercepted via CPDFReaderWidget.onInterceptWidgetActionCallback. Developers can handle displaying a custom combo box options dialog via the callback. Note: only support android platform in version 2.6.2
final
interceptListBoxAction bool
Intercept list box click event. Default is false (not intercepted), clicking the list box directly shows the list box options dialog. When set to true, the click event is intercepted via CPDFReaderWidget.onInterceptWidgetActionCallback. Developers can handle displaying a custom list box options dialog via the callback. Note: only support android platform in version 2.6.2
final
interceptPushButtonAction bool
Intercept button click event. Default is false (not intercepted), clicking the button directly triggers the button action. When set to true, the click event is intercepted via CPDFReaderWidget.onInterceptWidgetActionCallback. Developers can handle button click actions via the callback. Note: only support android platform in version 2.6.2
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCreateComboBoxOptionsDialog bool
final
showCreateListBoxOptionsDialog bool
final
showCreatePushButtonOptionsDialog bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited