CPDFGoToAction class
A class representing a GoTo action in a PDF document. This action navigates to a specified page within the document when triggered. It extends the CPDFAction class. The pageIndex property holds the index of the page to navigate to. Example usage:
// Create a GoTo action to navigate to page index 2
CPDFGoToAction action = CPDFGoToAction(pageIndex: 2);
- Inheritance
-
- Object
- CPDFAction
- CPDFGoToAction
Constructors
- CPDFGoToAction({required int pageIndex})
-
CPDFGoToAction.fromJson(Map<
String, dynamic> json) -
factory
Properties
- actionType ↔ CPDFActionType
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageIndex ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited