CPDFTextLine class page

Text line information on a PDF page.

Constructors

CPDFTextLine({required int pageIndex, required int lineIndex, required int location, required int length, required CPDFRectF rect})
const
CPDFTextLine.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Character count of this line.
final
lineIndex int
Line index in the page line collection, zero-based.
final
location int
Start character index of this line in the page text.
final
pageIndex int
Page index, zero-based.
final
rect CPDFRectF
Bounding rectangle of this line in page coordinates.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited