CPDFPageThumbnailDiskCache class abstract

Disk cache abstraction for page thumbnails.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clears all cached page thumbnails.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(CPDFPageThumbnailKey key) Future<Uint8List?>
Reads encoded image bytes for key.
remove(CPDFPageThumbnailKey key) Future<void>
Removes one cached thumbnail.
toString() String
A string representation of this object.
inherited
write(CPDFPageThumbnailKey key, Uint8List bytes) Future<void>
Writes encoded image bytes for key.

Operators

operator ==(Object other) bool
The equality operator.
inherited