CPDFPageThumbnailFileDiskCache class

File-system backed thumbnail cache.

Implemented types

Constructors

CPDFPageThumbnailFileDiskCache({Directory? cacheDirectory})
Creates a disk cache. When cacheDirectory is omitted, a dedicated subdirectory is created under ComPDFKit.getTemporaryDirectory.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clears all cached page thumbnails.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(CPDFPageThumbnailKey key) Future<Uint8List?>
Reads encoded image bytes for key.
override
remove(CPDFPageThumbnailKey key) Future<void>
Removes one cached thumbnail.
override
toString() String
A string representation of this object.
inherited
write(CPDFPageThumbnailKey key, Uint8List bytes) Future<void>
Writes encoded image bytes for key.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultDirectoryName → const String
Directory name under ComPDFKit.getTemporaryDirectory.