CPDFPageThumbnailCachePolicy enum

Cache behavior for page thumbnails.

Inheritance
Available extensions

Values

memoryOnly → const CPDFPageThumbnailCachePolicy

Use Flutter image cache only.

memoryAndDisk → const CPDFPageThumbnailCachePolicy

Use Flutter image cache and SDK disk cache.

diskOnly → const CPDFPageThumbnailCachePolicy

Use SDK disk cache without SDK in-memory encoded bytes cache.

noCache → const CPDFPageThumbnailCachePolicy

Skip SDK disk cache reads and writes.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
readsDisk bool
Whether the SDK disk cache can be read.
no setter
readsMemory bool
Whether the in-memory encoded bytes cache can be read.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writesDisk bool
Whether the SDK disk cache can be written.
no setter
writesMemory bool
Whether the in-memory encoded bytes cache can be written.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CPDFPageThumbnailCachePolicy>
A constant List of the values in this enum, in order of their declaration.