CPDFDocumentPageThumbnailRenderer class
Default renderer backed by CPDFDocument.
- Implemented types
Constructors
- CPDFDocumentPageThumbnailRenderer()
-
Creates a document renderer.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPageMetrics(
CPDFPageThumbnailSource source, int pageIndex) → Future< CPDFPageThumbnailPageMetrics> -
Returns the page metrics for
source.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
CPDFPageThumbnailKey key) → Future< Uint8List> -
Renders
keyto encoded image bytes.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited