CPDFPageThumbnailService class
Coordinates thumbnail key resolution, cache lookup, and rendering.
Constructors
- CPDFPageThumbnailService({CPDFPageThumbnailRenderer renderer = const CPDFDocumentPageThumbnailRenderer(), CPDFPageThumbnailDiskCache diskCache = const CPDFPageThumbnailFileDiskCache()})
- Creates a thumbnail service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCache(
) → Future< void> - Clears all SDK disk cache entries.
-
evict(
CPDFPageThumbnailKey key) → Future< void> -
Removes the SDK disk cache entry for
key. -
load(
CPDFPageThumbnailKey key) → Future< Uint8List> -
Loads encoded thumbnail bytes for
key. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveKey(
{required CPDFPageThumbnailSource source, required int pageIndex, required CPDFPageThumbnailOptions options}) → Future< CPDFPageThumbnailKey> - Resolves an immutable provider key.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
Shared default service.
no setter