CPDFPageThumbnail class

Builds a PDF page thumbnail image with placeholder and error handling.

Inheritance

Constructors

CPDFPageThumbnail({Key? key, required CPDFPageThumbnailSource source, required int pageIndex, CPDFPageThumbnailOptions options = const CPDFPageThumbnailOptions(), CPDFPageThumbnailService? service, bool useFlutterImageCache = true, WidgetBuilder? placeholderBuilder, ImageErrorWidgetBuilder? errorBuilder, BoxFit? fit, AlignmentGeometry alignment = Alignment.center, FilterQuality filterQuality = FilterQuality.low, String? semanticLabel, bool excludeFromSemantics = false, CPDFPageThumbnailImageBuilder? imageBuilder})
Creates a thumbnail widget.
const
CPDFPageThumbnail.document({Key? key, required CPDFDocument document, required int pageIndex, CPDFPageThumbnailOptions options = const CPDFPageThumbnailOptions(), Object? cacheVersion, CPDFPageThumbnailService? service, bool useFlutterImageCache = true, WidgetBuilder? placeholderBuilder, ImageErrorWidgetBuilder? errorBuilder, BoxFit? fit, AlignmentGeometry alignment = Alignment.center, FilterQuality filterQuality = FilterQuality.low, String? semanticLabel, bool excludeFromSemantics = false})
Creates a thumbnail widget from an existing document.
CPDFPageThumbnail.file({Key? key, required String filePath, required int pageIndex, String password = '', CPDFPageThumbnailOptions options = const CPDFPageThumbnailOptions(), CPDFPageThumbnailService? service, bool useFlutterImageCache = true, WidgetBuilder? placeholderBuilder, ImageErrorWidgetBuilder? errorBuilder, BoxFit? fit, AlignmentGeometry alignment = Alignment.center, FilterQuality filterQuality = FilterQuality.low, String? semanticLabel, bool excludeFromSemantics = false})
Creates a thumbnail widget from a file path.
CPDFPageThumbnail.test({Key? key, required CPDFPageThumbnailSource source, required int pageIndex, CPDFPageThumbnailOptions options = const CPDFPageThumbnailOptions(), CPDFPageThumbnailService? service, bool useFlutterImageCache = true, WidgetBuilder? placeholderBuilder, ImageErrorWidgetBuilder? errorBuilder, BoxFit? fit, AlignmentGeometry alignment = Alignment.center, FilterQuality filterQuality = FilterQuality.low, String? semanticLabel, bool excludeFromSemantics = false, required CPDFPageThumbnailImageBuilder imageBuilder})
Creates a thumbnail widget for tests without starting image decoding.
const

Properties

alignment AlignmentGeometry
Image alignment.
final
errorBuilder ImageErrorWidgetBuilder?
Error widget builder.
final
excludeFromSemantics bool
Excludes semantics when true.
final
filterQuality FilterQuality
Image filter quality.
final
fit BoxFit?
Image fit.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
options CPDFPageThumbnailOptions
Render options.
final
pageIndex int
Page index to render.
final
placeholderBuilder WidgetBuilder?
Placeholder shown before the first image frame.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
Semantic label.
final
service CPDFPageThumbnailService?
Service used to load thumbnails.
final
source CPDFPageThumbnailSource
Thumbnail source.
final
useFlutterImageCache bool
Whether Flutter's decoded image cache is used before SDK caches.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited